<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr_TR">
<context>
    <name>BlackoutWidget</name>
    <message>
        <source>Click to Return to Application</source>
        <translation>Uygylamaya Geri Dönmek için Tıklayın</translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>Downloads</source>
        <translation>İndirilenler</translation>
    </message>
    <message>
        <source>Clean Up</source>
        <translation>Temizle</translation>
    </message>
    <message>
        <source>0 Items</source>
        <translation>Kalem</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Form</source>
        <translation>Gönderen</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Dosya Adı</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Yeniden Dene</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Durdur</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Aç</translation>
    </message>
</context>
<context>
    <name>IntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>Kaydı YouTube&apos;da Yayınla</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Başlık</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Açıklama</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Yazar</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Board</source>
        <translation>Tahta</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dökümanlar</translation>
    </message>
    <message>
        <source>Stylus</source>
        <translation>Kalem</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Backgrounds</source>
        <translation>Arkaplanlar</translation>
    </message>
    <message>
        <source>Change Background</source>
        <translation>Arkaplanı Değiştir</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Geri Al</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Yeniden</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Önceki</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>Önceki Sayfa</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>SyYukari</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Sonraki</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>Sonraki Sayfa</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>SyAşağı</translation>
    </message>
    <message>
        <source>Manage Documents</source>
        <translation>Dökümanları Yönet</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>Web Browsing</source>
        <translation>Web Gezintisi</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Çık</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Geri</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Sol</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>İleri</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Sağ</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Yeniden Yükle</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Ana Sayfa</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Sık Kullanılanlar</translation>
    </message>
    <message>
        <source>Bookmark</source>
        <translation>Sık Kullanılan</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>Erase</source>
        <translation>Sil</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation>Seçenekler</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>Kütüphane</translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <source>Show Desktop</source>
        <translation>Masaüstünü Göster</translation>
    </message>
    <message>
        <source>Bigger</source>
        <translation>Daha Büyük</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Smaller</source>
        <translation>Daha Küçük</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Yeni Klasör</translation>
    </message>
    <message>
        <source>New Document</source>
        <translation>Yeni Döküman</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>İçeri Aktar</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Dışarı Aktar</translation>
    </message>
    <message>
        <source>Open in Board</source>
        <translation>Tahta da Aç</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Kopyala</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Sil</translation>
    </message>
    <message>
        <source>Add to Working Document</source>
        <translation>Aktif Dökümana Ekle</translation>
    </message>
    <message>
        <source>Add Selected Content to Open Document</source>
        <translation>Seçili İçeriği Aktif Dökümana Ekle</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Ekle</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Yeniden Adlandır</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Araçlar</translation>
    </message>
    <message>
        <source>Multi Screen</source>
        <translation>Çoklu Ekran</translation>
    </message>
    <message>
        <source>Wide Size (16/9)</source>
        <translation>Geniş Ekran Boyutu (16/9)</translation>
    </message>
    <message>
        <source>Regular Size (4/3)</source>
        <translation>Nprmal Ekran Boyutu (4/3)</translation>
    </message>
    <message>
        <source>Custom Size</source>
        <translation>Özel Ekran Boyutu</translation>
    </message>
    <message>
        <source>Stop Loading</source>
        <translation>Yüklemeyi Durdur</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Kes</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopyala</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Yapıştır</translation>
    </message>
    <message>
        <source>Sleep</source>
        <translation>Uyut</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>Sanal Klavye</translation>
    </message>
    <message>
        <source>Plain Light Background</source>
        <translation>Sade Açık Arkaplan</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Açık</translation>
    </message>
    <message>
        <source>Grid Light Background</source>
        <translation>Açık Izgara Arkaplan</translation>
    </message>
    <message>
        <source>Plain Dark Background</source>
        <translation>Sade Kapalı Arkaplan</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Kapalı</translation>
    </message>
    <message>
        <source>Grid Dark Background</source>
        <translation>Kapalı Izgara Arkaplan</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>Ekran Kaydı</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Kayıt</translation>
    </message>
    <message>
        <source>Start Screen Recording</source>
        <translation>Ekran Kaydını Başlat</translation>
    </message>
    <message>
        <source>Erase Items</source>
        <translation>Kalemleri Sil</translation>
    </message>
    <message>
        <source>Erase Annotations</source>
        <translation>Açıklamaları Sil</translation>
    </message>
    <message>
        <source>Clear Page</source>
        <translation>Sayfayı Temizle</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Dolmakalem</translation>
    </message>
    <message>
        <source>Check Update</source>
        <translation>Güncellemeleri Denetle</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <source>Eraser</source>
        <translation>Silgi</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Fosforlu Kalem</translation>
    </message>
    <message>
        <source>Selector</source>
        <translation>Seçici</translation>
    </message>
    <message>
        <source>Hand</source>
        <translation>El</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>Yakınlaştır</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>Uzaklaştır</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Çizgi</translation>
    </message>
    <message>
        <source>Small Line</source>
        <translation>Ufak Çizgi</translation>
    </message>
    <message>
        <source>Medium Line</source>
        <translation>Normal Çizgi</translation>
    </message>
    <message>
        <source>Large Line</source>
        <translation>Kalın Çizgi</translation>
    </message>
    <message>
        <source>Smalle Eraser</source>
        <translation type="vanished">Küçük Silgi</translation>
    </message>
    <message>
        <source>Medium Eraser</source>
        <translation>Normal Silgi</translation>
    </message>
    <message>
        <source>Large Eraser</source>
        <translation>Büyük Silgi</translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="vanished">Renkler</translation>
    </message>
    <message>
        <source>Reload Current Page</source>
        <translation>Mevcut Sayfayı Yeniden Yükle</translation>
    </message>
    <message>
        <source>Load Home Page</source>
        <translation>Ana Sayfayı Yükle</translation>
    </message>
    <message>
        <source>Show Bookmarks</source>
        <translation>Sık Kullanılanları Göster</translation>
    </message>
    <message>
        <source>Add Bookmark</source>
        <translation>Sık Kullanılana Ekle</translation>
    </message>
    <message>
        <source>Display Board</source>
        <translation>Tahtayı Göster</translation>
    </message>
    <message>
        <source>Erase Content</source>
        <translation>İçeriği Sil</translation>
    </message>
    <message>
        <source>Display Preferences</source>
        <translation>Seçenekleri Göster</translation>
    </message>
    <message>
        <source>Show Library</source>
        <translation>Kütüphaneyi Göster</translation>
    </message>
    <message>
        <source>Show Computer Desktop</source>
        <translation>Bilgisayar Masaüstünü Göster</translation>
    </message>
    <message>
        <source>Ctrl+Shift+H</source>
        <translation>Ctrl+Shift+H</translation>
    </message>
    <message>
        <source>Create a New Folder</source>
        <translation>Yeni Klasör Oluştur</translation>
    </message>
    <message>
        <source>Create a New Document</source>
        <translation>Yeni Döküman Oluştur</translation>
    </message>
    <message>
        <source>Import a Document</source>
        <translation>Dökümanı İçeri Aktar</translation>
    </message>
    <message>
        <source>Export a Document</source>
        <translation>Dökümanı Dışa Aktar</translation>
    </message>
    <message>
        <source>Open Page in Board</source>
        <translation>Sayfayı Tahtada Aç</translation>
    </message>
    <message>
        <source>Duplicate Selected Content</source>
        <translation>Seçili İçeriği Çoğalt</translation>
    </message>
    <message>
        <source>Delete Selected Content</source>
        <translation>Seçili İçeriği Sil</translation>
    </message>
    <message>
        <source>Add Content to Document</source>
        <translation>İçeriği Dökümana Ekle</translation>
    </message>
    <message>
        <source>Rename Content</source>
        <translation>İçeriği Yeniden Adlandır</translation>
    </message>
    <message>
        <source>Display Tools</source>
        <translation>Araçları Göster</translation>
    </message>
    <message>
        <source>Use Document Wide Size (16/9)</source>
        <translation>Dökümanı Geniş Boy Olarak Kullan (16/9)</translation>
    </message>
    <message>
        <source>Use Document Regular Size (4/3)</source>
        <translation>Dökümanı Normal Boy Olarak Kullan (4/3)</translation>
    </message>
    <message>
        <source>Use Custom Document Size</source>
        <translation>Özel Döküman Boyutu Kullan</translation>
    </message>
    <message>
        <source>Stop Loading Web Page</source>
        <translation>Web Sayfasını Yüklemeyi Durdur</translation>
    </message>
    <message>
        <source>Put Presentation to Sleep</source>
        <translation>Sunumu Uyku Moduna Al</translation>
    </message>
    <message>
        <source>Display Virtual Keyboard</source>
        <translation>Sanal Klavyeyi Göster</translation>
    </message>
    <message>
        <source>Record Presentation to Video</source>
        <translation>Sunumu Video Olarak Kaydet</translation>
    </message>
    <message>
        <source>Erase All Items</source>
        <translation>Tüm  Kalemleri Sil</translation>
    </message>
    <message>
        <source>Erase All Annotations</source>
        <translation>Tüm Açıklamaları Sil</translation>
    </message>
    <message>
        <source>Clear All Elements</source>
        <translation>Tüm Öğeleri Sil</translation>
    </message>
    <message>
        <source>Annotate Document</source>
        <translation>Dökümana Açıklama Gir</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Erase Annotation</source>
        <translation>Açıklamayı Sil</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Highlight </source>
        <translation>Vurgu</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Select And Modify Objects</source>
        <translation>Objeyi Seç ve Değiştir</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Scroll Page</source>
        <translation>Sayfayı Kaydır</translation>
    </message>
    <message>
        <source>Laser Pointer</source>
        <translation>Lazer İşaretçi</translation>
    </message>
    <message>
        <source>Virtual Laser Pointer</source>
        <translation>Sanal Lazer İşaretçi</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Draw Lines</source>
        <translation>Çizgi Çiz</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Metin</translation>
    </message>
    <message>
        <source>Write Text</source>
        <translation>Metin Yaz</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation>Yakala</translation>
    </message>
    <message>
        <source>Add To Current Page</source>
        <translation>Mevcut Sayfaya Ekle</translation>
    </message>
    <message>
        <source>Add Item To Current Page</source>
        <translation>Kalemleri Mevut Sayfaya Ekle</translation>
    </message>
    <message>
        <source>Add To New Page</source>
        <translation>Yeni Sayfaya Ekle</translation>
    </message>
    <message>
        <source>Add Item To New Page</source>
        <translation>Kalemleri Yeni Sayfaya Ekle</translation>
    </message>
    <message>
        <source>Add To Library</source>
        <translation>Kütüphaneye Ekle</translation>
    </message>
    <message>
        <source>Add Item To Library</source>
        <translation>Kalemi Kütüphaneye Ekle</translation>
    </message>
    <message>
        <source>Pages</source>
        <translation>Sayfalar</translation>
    </message>
    <message>
        <source>Create a New Page</source>
        <translation>Yeni Sayfa Oluştur</translation>
    </message>
    <message>
        <source>New Page</source>
        <translation>Yeni Sayfa</translation>
    </message>
    <message>
        <source>Duplicate Page</source>
        <translation>Sayfayı Çoğalt</translation>
    </message>
    <message>
        <source>Duplicate the Current Page</source>
        <translation>Mevcut Sayfayı Çoğalt</translation>
    </message>
    <message>
        <source>Import Page</source>
        <translation>Sayfayı İçeri Aktar</translation>
    </message>
    <message>
        <source>Import an External Page</source>
        <translation>Harici Sayfayı İçeri Aktar</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Durdur</translation>
    </message>
    <message>
        <source>Pause Podcast Recording</source>
        <translation>Ekran Kaydını Durdur</translation>
    </message>
    <message>
        <source>Podcast Config</source>
        <translation>Ekran Kayıt Ayarları</translation>
    </message>
    <message>
        <source>Configure Podcast Recording</source>
        <translation>Ekran Kaydını Ayarla</translation>
    </message>
    <message>
        <source>Flash Trap</source>
        <translation>Flash Tuzağı</translation>
    </message>
    <message>
        <source>Trap Flash Content</source>
        <translation>Flash İçeriğini Yakala</translation>
    </message>
    <message>
        <source>Web Trap</source>
        <translation>Webi Tuzağı</translation>
    </message>
    <message>
        <source>Trap Web Content</source>
        <translation>Web İçeriğini Yakala</translation>
    </message>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>Ekranın Bir Bölümünü Yakala</translation>
    </message>
    <message>
        <source>Custom Capture</source>
        <translation>Özel Yakala</translation>
    </message>
    <message>
        <source>Capture a Window</source>
        <translation>Bir Pencereyi Yakala</translation>
    </message>
    <message>
        <source>Embed Web Content</source>
        <translation>Web İçeriğini Göm</translation>
    </message>
    <message>
        <source>Capture Embeddable Web Content</source>
        <translation>Gömülü Web İçeriğini Yakala</translation>
    </message>
    <message>
        <source>Show Main Screen on Display Screen</source>
        <translation>Görüntü Ekranında Ana Ekranı Göster</translation>
    </message>
    <message>
        <source>Erase all Annotations</source>
        <translation>Tüm Açıklamaları Sil</translation>
    </message>
    <message>
        <source>eduMedia</source>
        <translation>eduMedya</translation>
    </message>
    <message>
        <source>Import eduMedia simulation</source>
        <translation>eduMedya Simülasyon&apos;u İçeri Aktar</translation>
    </message>
    <message>
        <source>Window Capture</source>
        <translation>Pencere Yakala</translation>
    </message>
    <message>
        <source>Show on Display</source>
        <translation>Ekranda Göster</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation>OpenBoard</translation>
    </message>
    <message>
        <source>Quit OpenBoard</source>
        <translation>Open-Sankpré&apos;den Çık</translation>
    </message>
    <message>
        <source>Hide OpenBoard</source>
        <translation>OpenBoard&apos;i Gizle</translation>
    </message>
    <message>
        <source>Hide OpenBoard Application</source>
        <translation>OpenBoard Uygulamasını Gizle</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Oynat</translation>
    </message>
    <message>
        <source>Interact with items</source>
        <translation>Parçalar ile etkileşim</translation>
    </message>
    <message>
        <source>Erase Background</source>
        <translation>Arkaplanı Sil</translation>
    </message>
    <message>
        <source>Remove the backgound</source>
        <translation>Arkaplanı Kaldır</translation>
    </message>
    <message>
        <source>Ruled Light Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ruled Dark Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Tutorial</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open the tutorial web page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset grid size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Small Eraser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Kimlik Doğrulama Yapınız</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Kullanıcı Adı:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Şifre:</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Proxy Authentication</source>
        <translation>Proxy Doğrulama</translation>
    </message>
    <message>
        <source>Connect to Proxy</source>
        <translation>Proxy&apos;e Bağlan</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Kullanıcı Adı:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Şifre:</translation>
    </message>
    <message>
        <source>Save username and password for future use</source>
        <translation>Kullanıcı adı ve şifresini kaydet</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Element ID = </source>
        <translation>Element ID = </translation>
    </message>
    <message>
        <source>Content is not supported in destination format.</source>
        <translation>İçerik hedef içerik için uygun geğil.</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation>Sayfayı Kaldır</translation>
    </message>
    <message>
        <source>Are you sure you want to remove 1 page from the selected document &apos;%0&apos;?</source>
        <translation>Seçili olan &apos;%0&apos; adlı dökümandan 1 sayfayı kaldırmak üzeresiniz. Bu işlemi yapmak istediğinizden eminmisiniz?</translation>
    </message>
</context>
<context>
    <name>UBApplication</name>
    <message>
        <source>Page Size</source>
        <translation>Sayfa Boyutu</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>Ekran Kaydı</translation>
    </message>
</context>
<context>
    <name>UBApplicationController</name>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
    <message>
        <source>New update available, would you go to the web page ?</source>
        <translation>Yeni güncellemeler var. Web sitesine giderek indirmek istermisiniz?</translation>
    </message>
    <message>
        <source>No update available</source>
        <translation>Yeni güncelleme yok</translation>
    </message>
    <message>
        <source>Update available</source>
        <translation>Güncelleme var</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Güncelle</translation>
    </message>
</context>
<context>
    <name>UBBackgroundPalette</name>
    <message>
        <source>Grid size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBBoardController</name>
    <message>
        <source>Downloading content %1 failed</source>
        <translation>İçeriğin %1&apos;i indirilemedi</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>İndirme tamamlandı</translation>
    </message>
    <message>
        <source>Unknown tool type %1</source>
        <translation>Bilinmeyen araç türü %1</translation>
    </message>
    <message>
        <source>Unknown content type %1</source>
        <translation>Bilinmeyen içerik türü %1</translation>
    </message>
    <message>
        <source>Add Item</source>
        <translation>Parça Ekle</translation>
    </message>
    <message>
        <source>All Supported (%1)</source>
        <translation>Tümü Desteklenir (%1)</translation>
    </message>
    <message>
        <source>Delete page %1 from document</source>
        <translation type="vanished">%1 Sayfayı dökümandan sil</translation>
    </message>
    <message>
        <source>Page %1 deleted</source>
        <translation>%1 Sayfa silindi</translation>
    </message>
    <message>
        <source>Add file operation failed: file copying error</source>
        <translation>Dosya ekleme işlemi başarısız oldu: dosya kopyalama hatası</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Grup</translation>
    </message>
    <message>
        <source>Ungroup</source>
        <translation>Gurubu Ayır</translation>
    </message>
    <message>
        <source>Saving document...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document has just been saved...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deleting page %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="unfinished">Renkler</translation>
    </message>
</context>
<context>
    <name>UBBoardPaletteManager</name>
    <message>
        <source>Error Adding Image to Library</source>
        <translation>Kütüphaneye Resim Eklerken Hata Oluştu</translation>
    </message>
    <message>
        <source>CapturedImage</source>
        <translation>YakalananResim</translation>
    </message>
</context>
<context>
    <name>UBBoardThumbnailsView</name>
    <message>
        <source>Loading page (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBCachePropertiesWidget</name>
    <message>
        <source>Cache Properties</source>
        <translation>Gizleme Seçenekleri</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Renk:</translation>
    </message>
    <message>
        <source>Shape:</source>
        <translation>Şekil:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Boyut:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
</context>
<context>
    <name>UBDesktopPalette</name>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>Ekranın Bir Bölümünü Yakala</translation>
    </message>
    <message>
        <source>Capture the Screen</source>
        <translation>Ekranı Yakala</translation>
    </message>
    <message>
        <source>Show the stylus palette</source>
        <translation>Kalem paletini göster</translation>
    </message>
    <message>
        <source>Show Board on Secondary Screen</source>
        <translation>Tahtayı İkincil Ekranda Göster</translation>
    </message>
    <message>
        <source>Show Desktop on Secondary Screen</source>
        <translation>Masaüstünü İkincil Ekranda Göster</translation>
    </message>
    <message>
        <source>Show OpenBoard</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentController</name>
    <message>
        <source>New Folder</source>
        <translation>Yeni Klasör</translation>
    </message>
    <message>
        <source>Page %1</source>
        <translation>Sayfa %1</translation>
    </message>
    <message>
        <source>Add Folder of Images</source>
        <translation>Resim Klasörü Ekle</translation>
    </message>
    <message>
        <source>Add Images</source>
        <translation>Resimleri Ekle</translation>
    </message>
    <message>
        <source>Add Pages from File</source>
        <translation>Dosyadan Sayfa Ekle</translation>
    </message>
    <message>
        <source>Duplicating Document %1</source>
        <translation>%1 Dökümanı Çoğalt</translation>
    </message>
    <message>
        <source>Document %1 copied</source>
        <translation>%1 Döküman kopyalandı</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation type="vanished">Sayfayı Kaldır</translation>
    </message>
    <message>
        <source>Remove Document</source>
        <translation type="vanished">Dökümanı Kaldır</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the document &apos;%1&apos;?</source>
        <translation type="vanished">%1 adlı dökümanı kaldırmak istediğinizden eminmisiniz?</translation>
    </message>
    <message>
        <source>Empty Trash</source>
        <translation type="vanished">Çöpü Boşalt</translation>
    </message>
    <message>
        <source>Are you sure you want to empty trash?</source>
        <translation type="vanished">Çöp kutusunu boşaltmak istediğinizden eminmisiniz?</translation>
    </message>
    <message>
        <source>Emptying trash</source>
        <translation type="vanished">Çöp Kutusu boşaltılıyor</translation>
    </message>
    <message>
        <source>Emptied trash</source>
        <translation type="vanished">Çöp kutusu boşaltıldı</translation>
    </message>
    <message>
        <source>Remove Folder</source>
        <translation type="vanished">Klasörü Kaldır</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the folder &apos;%1&apos; and all its content?</source>
        <translation type="vanished">&apos;%1&apos; adlı klasörü ve içindeki tüm dosyaları kaldırmak istediğinizden eminmisiniz?</translation>
    </message>
    <message>
        <source>No document selected!</source>
        <translation type="vanished">Seçili döküman yok!</translation>
    </message>
    <message>
        <source>Open Supported File</source>
        <translation>Desteklenen Dosyayı Aç</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>%1 adlı dosya içeriye aktarılıyor...</translation>
    </message>
    <message>
        <source>Failed to import file ... </source>
        <translation>Dosya içeriye aktarılamadı ...</translation>
    </message>
    <message>
        <source>Import all Images from Folder</source>
        <translation>Klasördeki Tüm Resimleri İçeri Aktar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Boşalt</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>Çöp</translation>
    </message>
    <message>
        <source>Open Document</source>
        <translation>Döküman Aç</translation>
    </message>
    <message>
        <source>Add all Images to Document</source>
        <translation>Tüm Resimleri Dökümana Ekle</translation>
    </message>
    <message>
        <source>All Images (%1)</source>
        <translation>Tüm Resimler (%1)</translation>
    </message>
    <message>
        <source>Selection does not contain any image files!</source>
        <translation>Seçilenlerin arasında hiç resim bulunmamaktadır!</translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to remove %n page(s) from the selected document &apos;%1&apos;?</source>
        <translation type="vanished">
            <numerusform>Seçili &apos;%1&apos; adlı dökümandan %n sayfayı kaldırmak istediğinizden eminmisiniz?</numerusform>
        </translation>
    </message>
    <message>
        <source>Folder does not contain any image files</source>
        <translation>Klasör hiç resim dosyası içermiyor</translation>
    </message>
    <message>
        <source>Untitled Documents</source>
        <translation>Başlıksız Döküman</translation>
    </message>
    <message numerus="yes">
        <source>duplicated %1 page</source>
        <comment>duplicated %1 pages</comment>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The document &apos;%1&apos; has been generated with a newer version of OpenBoard (%2). By opening it, you may lose some information. Do you want to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title page</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentManager</name>
    <message>
        <source>images</source>
        <translation>resimler</translation>
    </message>
    <message>
        <source>videos</source>
        <translation>videolar</translation>
    </message>
    <message>
        <source>objects</source>
        <translation>öğeler</translation>
    </message>
    <message>
        <source>widgets</source>
        <translation>widgetlar</translation>
    </message>
    <message>
        <source>All supported files (*.%1)</source>
        <translation>Desteklenen tüm dosyalar (*.%1)</translation>
    </message>
    <message>
        <source>File %1 saved</source>
        <translation>%1 adlı dosya kaydedildi</translation>
    </message>
    <message>
        <source>Inserting page %1 of %2</source>
        <translation>%1 / %2 Sayfa ekleniyor</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>İçe aktarım tamamlandı.</translation>
    </message>
    <message>
        <source>Import of file %1 successful.</source>
        <translation>%1 Adlı dosya içeriye aktarıldı.</translation>
    </message>
    <message>
        <source>Importing file %1</source>
        <translation>İçe aktarılan dosya: %1</translation>
    </message>
</context>
<context>
    <name>UBDocumentNavigator</name>
    <message>
        <source>Page %0</source>
        <translation>Sayfa %0</translation>
    </message>
</context>
<context>
    <name>UBDocumentReplaceDialog</name>
    <message>
        <source>Accept</source>
        <translation type="unfinished">Kabul Et</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">İptal</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The name %1 is allready used.
Keeping this name will replace the document.
Providing a new name will create a new document.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeModel</name>
    <message>
        <source>Trash</source>
        <translation type="unfinished">Çöp</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="unfinished">
            <numerusform>%1 sayfa kopyalandı</numerusform>
        </translation>
    </message>
    <message>
        <source>My documents</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeView</name>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="unfinished">
            <numerusform>%1 sayfa kopyalandı</numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="unfinished">Kopyalanan sayfa %1/%2</translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeWidget</name>
    <message>
        <source>%1 (copy)</source>
        <translation type="vanished">%1 (kopyala)</translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="vanished">Kopyalanan sayfa %1/%2</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translatorcomment>The translation is correct but it is giving error message.</translatorcomment>
        <translation type="vanished">
            <numerusform>%1 sayfa kopyalandı</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>UBDownloadWidget</name>
    <message>
        <source>Downloading files</source>
        <translation>Dosyalar indiriliyor</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnail</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">Sayfa %0</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnailView</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">Sayfa %0</translation>
    </message>
</context>
<context>
    <name>UBExportAdaptor</name>
    <message>
        <source>Warnings during export was appeared</source>
        <translation>Dışa aktarma sırasında bir uyarı mesajı göründü</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="unfinished">Döküman dışa aktarılıyor...</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to export to the selected location. You do not have the permissions necessary to save the file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export failed: location not writable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportCFF</name>
    <message>
        <source>Export to IWB</source>
        <translation>IWB&apos;e Aktar</translation>
    </message>
    <message>
        <source>Export as IWB File</source>
        <translation>IWB Dosyası Olarak Aktar</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Döküman dışa aktarılıyor...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Dışa aktarma tamamlandı.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>Dışa aktarma başarısız oldu.</translation>
    </message>
</context>
<context>
    <name>UBExportDocument</name>
    <message>
        <source>Page</source>
        <translation>Sayfa</translation>
    </message>
    <message>
        <source>Export as UBZ File</source>
        <translation>UBZ Dosyası Olarak Aktar</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Döküman dışa aktarılıyor...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Dışa aktarım tamamlandı.</translation>
    </message>
    <message>
        <source>Exporting %1 %2 of %3</source>
        <translation>Dışa Aktarılan %1 %2 / %3</translation>
    </message>
    <message>
        <source>Export to OpenBoard Format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportDocumentSetAdaptor</name>
    <message>
        <source>Exporting document...</source>
        <translation type="unfinished">Döküman dışa aktarılıyor...</translation>
    </message>
    <message>
        <source>Failed to export...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export as UBX File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export to OpenBoard UBX Format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportFullPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>PDF Dosyası Olarak Dışa Aktar</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Döküman dışa aktarılıyor...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Dışa aktarım tamamlandı.</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>PDF Olarak Aktar</translation>
    </message>
</context>
<context>
    <name>UBExportPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>PDF Dosyası Olarak Dışa Aktar</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Döküman dışa aktarılıyor...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Dışa aktarım tamamlandı.</translation>
    </message>
    <message>
        <source>Exporting page %1 of %2</source>
        <translation>Dışa aktarılan sayfa: %1 / %2</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>PDF Olark Aktar</translation>
    </message>
</context>
<context>
    <name>UBExportWeb</name>
    <message>
        <source>Page</source>
        <translation>Sayfa</translation>
    </message>
    <message>
        <source>Export as Web data</source>
        <translation>Web Verisi Olarak Dışa Aktar</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Döküman dışa aktarılıyor...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Dışa aktarım tamamlandı.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>Dışa aktarım başarısız oldu.</translation>
    </message>
    <message>
        <source>Export to Web Browser</source>
        <translation>Web Tarayıcısına Aktar</translation>
    </message>
</context>
<context>
    <name>UBFeatureProperties</name>
    <message>
        <source>Add to page</source>
        <translation>Sayfaya ekle</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation type="vanished">Arkaplan olarak tanımla</translation>
    </message>
    <message>
        <source>Add to library</source>
        <translation>Kütüphaneye ekle</translation>
    </message>
    <message>
        <source>Object informations</source>
        <translation>Nesne bilgisi</translation>
    </message>
</context>
<context>
    <name>UBFeaturesActionBar</name>
    <message>
        <source>Add to favorites</source>
        <translation>Sık kullanılanlara ekle</translation>
    </message>
    <message>
        <source>Share</source>
        <translation>Paylaş</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Ara</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <source>Back to folder</source>
        <translation>Klasöre geri dön</translation>
    </message>
    <message>
        <source>Remove from favorites</source>
        <translation>Sık kullanılanlardan kaldır</translation>
    </message>
    <message>
        <source>Create new folder</source>
        <translation>Yeni klasör oluştur</translation>
    </message>
    <message>
        <source>Rescan file system</source>
        <translation>Dosya sistemini yeniden tara</translation>
    </message>
</context>
<context>
    <name>UBFeaturesController</name>
    <message>
        <source>ImportedImage</source>
        <translation>İçerAktarılanResim</translation>
    </message>
    <message>
        <source>Audios</source>
        <translation>Sesler</translation>
    </message>
    <message>
        <source>Movies</source>
        <translation>Videolar</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Resimler</translation>
    </message>
    <message>
        <source>Animations</source>
        <translation type="vanished">Animasyonlar</translation>
    </message>
    <message>
        <source>Interactivities</source>
        <translation>İnteraktiviteler</translation>
    </message>
    <message>
        <source>Applications</source>
        <translation>Uygulamalar</translation>
    </message>
    <message>
        <source>Shapes</source>
        <translation>Şekiller</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Sık Kullanılanlar</translation>
    </message>
    <message>
        <source>Web search</source>
        <translation>Web&apos;de Ara</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>Çöp</translation>
    </message>
</context>
<context>
    <name>UBFeaturesNewFolderDialog</name>
    <message>
        <source>Accept</source>
        <translation>Kabul Et</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Enter a new folder name</source>
        <translation>Yeni klasör adı giriniz</translation>
    </message>
</context>
<context>
    <name>UBFeaturesProgressInfo</name>
    <message>
        <source>Loading </source>
        <translation>Yükleniyor</translation>
    </message>
</context>
<context>
    <name>UBGraphicsGroupContainerItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>Kilitli</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>Uzatılmış Ekranda Görünsün</translation>
    </message>
</context>
<context>
    <name>UBGraphicsItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>Kilitli</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>Uzatılmış Ekranda Görünsün</translation>
    </message>
    <message>
        <source>Go to Content Source</source>
        <translation>İçerik Kaynağına Git</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation type="unfinished">Arkaplan olarak tanımla</translation>
    </message>
</context>
<context>
    <name>UBGraphicsMediaItem</name>
    <message>
        <source>Media resource couldn&apos;t be resolved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unsupported media format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media playback service not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media error: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItem</name>
    <message>
        <source>&lt;Type Text Here&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItemDelegate</name>
    <message>
        <source>Text Color</source>
        <translation>Metin Rengi</translation>
    </message>
    <message>
        <source>Editable</source>
        <translation>Düzenlenebilir</translation>
    </message>
</context>
<context>
    <name>UBGraphicsW3CWidgetItem</name>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItem</name>
    <message>
        <source>Loading ...</source>
        <translation>Yükleniyor ...</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItemDelegate</name>
    <message>
        <source>Frozen</source>
        <translation>Donmuş</translation>
    </message>
    <message>
        <source>Transform as Tool </source>
        <translation>Araç Olarak Dönüştür</translation>
    </message>
</context>
<context>
    <name>UBImportCFF</name>
    <message>
        <source>Common File Format (</source>
        <translation>Genel Dosya Biçimi (</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>İçe aktarılan dosya: %1...</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>%1 adlı dosya içe aktarılamadı.</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>İçe aktarım tamamlandı.</translation>
    </message>
    <message>
        <source>Import failed.</source>
        <translation>İçe aktarım tamamlanmadı.</translation>
    </message>
</context>
<context>
    <name>UBImportDocument</name>
    <message>
        <source>Importing file %1...</source>
        <translation>%1 adlı dosya içe aktarılıyor...</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>İçe aktarım tamamlandı.</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>%1 adlı dosyanın içe aktarımı başarısız oldu.</translation>
    </message>
    <message>
        <source>OpenBoard (*.ubz)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBImportDocumentSetAdaptor</name>
    <message>
        <source>Openboard (set of documents) (*.ubx)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBImportImage</name>
    <message>
        <source>Image Format (</source>
        <translation>Resim Biçimi (</translation>
    </message>
</context>
<context>
    <name>UBImportPDF</name>
    <message>
        <source>Portable Document Format (*.pdf)</source>
        <translation>Taşınabilir Döküman Biçimi (*.pdf)</translation>
    </message>
    <message>
        <source>PDF import failed.</source>
        <translation>PDF dosya aktarımı başarısız oldu.</translation>
    </message>
    <message>
        <source>Importing page %1 of %2</source>
        <translation>İçe aktarılan sayfa: %1 / %2</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublisher</name>
    <message>
        <source>Error while publishing video to intranet (%1)</source>
        <translation>Videonun intranete yayını sırasında hata oluştu(%1)</translation>
    </message>
    <message>
        <source>Publishing to Intranet in progress %1 %</source>
        <translation>Internete durumu: %1 %</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish</source>
        <translation>Yayınla</translation>
    </message>
</context>
<context>
    <name>UBKeyboardPalette</name>
    <message>
        <source>Enter</source>
        <translation>Giriş</translation>
    </message>
</context>
<context>
    <name>UBMainWindow</name>
    <message>
        <source>Yes</source>
        <translation>Evet</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Hayır</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Tamam</translation>
    </message>
</context>
<context>
    <name>UBMessagesDialog</name>
    <message>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
</context>
<context>
    <name>UBNetworkAccessManager</name>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation>&lt;qt&gt; %2 kısmında bulunan &quot;%1&quot; için kullanıcı adı ve şifre giriniz&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>Failed to log to Proxy</source>
        <translation>Proxy&apos;e giriş yapılamadı</translation>
    </message>
    <message>
        <source>SSL Errors:

%1

%2

Do you want to ignore these errors for this host?</source>
        <translation>SSL Hatası:

%1

%2
Bu host için yukarıdaki hatalar yok sayılsın mı?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Evet</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Hayır</translation>
    </message>
</context>
<context>
    <name>UBOpenSankoreImporterWidget</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">İptal</translation>
    </message>
    <message>
        <source>Open-Sankore Documents Detected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open-Sankoré documents are present on your computer. It is possible to import them to OpenBoard by pressing the “Proceed” button to launch the importer application.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show this panel next time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can always access the OpenBoard Document Importer through the Preferences panel in the About tab. Warning, if you have already imported your Open-Sankore datas, you might loose your current OpenBoard documents.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proceed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPersistenceManager</name>
    <message>
        <source>(copy)</source>
        <translation>(kopyala)</translation>
    </message>
    <message>
        <source>Document Repository Loss</source>
        <translation>Döküman Deposu Kaybedildi</translation>
    </message>
    <message>
        <source>OpenBoard has lost access to the document repository &apos;%1&apos;. Unfortunately the application must shut down to avoid data corruption. Latest changes may be lost as well.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPlatformUtils</name>
    <message>
        <source>English</source>
        <translation>İngilizce</translation>
    </message>
    <message>
        <source>Russian</source>
        <translation>Rusça</translation>
    </message>
    <message>
        <source>German</source>
        <translation>Almanca</translation>
    </message>
    <message>
        <source>French</source>
        <translation>Fıransızca</translation>
    </message>
    <message>
        <source>Swiss French</source>
        <translation>İsveç Fıransızcası</translation>
    </message>
</context>
<context>
    <name>UBPodcastController</name>
    <message>
        <source>Failed to start encoder ...</source>
        <translation>Enkoder başlatılamadı...</translation>
    </message>
    <message>
        <source>No Podcast encoder available ...</source>
        <translation>Geçerli canlı yayın enkoderi bulunamadı ...</translation>
    </message>
    <message>
        <source>Part %1</source>
        <translation>Bölüm %1</translation>
    </message>
    <message>
        <source>on your desktop ...</source>
        <translation>masa üstünüzde ...</translation>
    </message>
    <message>
        <source>in folder %1</source>
        <translation>%1 adlı klasörün içinde</translation>
    </message>
    <message>
        <source>Podcast created %1</source>
        <translation>Canlı yayın oluşturuldu %1</translation>
    </message>
    <message>
        <source>Podcast recording error (%1)</source>
        <translation>Canlı yayın kayıt hatası (%1)</translation>
    </message>
    <message>
        <source>Default Audio Input</source>
        <translation>Varsayılan Ses Girişi</translation>
    </message>
    <message>
        <source>No Audio Recording</source>
        <translation>Hiç Ses Kaydı Yok</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Küçük</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Full</source>
        <translation>Tam</translation>
    </message>
    <message>
        <source>Publish to Intranet</source>
        <translation>İnternette Yayınlar</translation>
    </message>
    <message>
        <source>Publish to Youtube</source>
        <translation>YouTube&apos;da Yayınla</translation>
    </message>
    <message>
        <source>OpenBoard Cast</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPreferencesController</name>
    <message>
        <source>version: </source>
        <translation>versiyon:</translation>
    </message>
    <message>
        <source>Marker is pressure sensitive</source>
        <translation>İşaretçi basınca duyarlıdır</translation>
    </message>
</context>
<context>
    <name>UBProxyLoginDlg</name>
    <message>
        <source>Proxy Login</source>
        <translation type="vanished">Proxy Girişi</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation type="vanished">Kullanıcı Adı:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="vanished">Şifre:</translation>
    </message>
</context>
<context>
    <name>UBPublicationDlg</name>
    <message>
        <source>Publish document on the web</source>
        <translation type="vanished">Dökümanı web üzerinde yayınla</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="vanished">Başlık:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="vanished">Açıklama:</translation>
    </message>
    <message>
        <source>Publish</source>
        <translation type="vanished">Yayınla</translation>
    </message>
</context>
<context>
    <name>UBSettings</name>
    <message>
        <source>My Movies</source>
        <translation>Filimlerim</translation>
    </message>
</context>
<context>
    <name>UBStartupHintsPalette</name>
    <message>
        <source>Visible next time</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBTeacherBarWidget</name>
    <message>
        <source></source>
        <translation></translation>
    </message>
</context>
<context>
    <name>UBThumbnailAdaptor</name>
    <message>
        <source>Generating preview thumbnails ...</source>
        <translation>Önizleme resimleri oluşturuluyor ...</translation>
    </message>
    <message>
        <source>%1 thumbnails generated ...</source>
        <translation>%1 adet önizleme resmi oluşturuldu ...</translation>
    </message>
</context>
<context>
    <name>UBThumbnailTextItem</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">Sayfa %0</translation>
    </message>
</context>
<context>
    <name>UBToolsManager</name>
    <message>
        <source>Mask</source>
        <translation>Maske</translation>
    </message>
    <message>
        <source>Ruler</source>
        <translation>Cetvel</translation>
    </message>
    <message>
        <source>Compass</source>
        <translation>Pusula</translation>
    </message>
    <message>
        <source>Protractor</source>
        <translation>İletki</translation>
    </message>
    <message>
        <source>Triangle</source>
        <translation>Üçgen</translation>
    </message>
    <message>
        <source>Magnifier</source>
        <translation>Büyüteç</translation>
    </message>
    <message>
        <source>Cache</source>
        <translation>Gizli Yer</translation>
    </message>
    <message>
        <source>Axes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBTrapFlashController</name>
    <message>
        <source>Whole page</source>
        <translation>Tüm sayfa</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
</context>
<context>
    <name>UBUpdateDlg</name>
    <message>
        <source>Document updater</source>
        <translation>Döküman güncelleyici</translation>
    </message>
    <message>
        <source> files require an update.</source>
        <translation>güncelleme için gerekli dosyalar.</translation>
    </message>
    <message>
        <source>Backup path: </source>
        <translation>Yedek yolu:</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Gözat</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Güncelle</translation>
    </message>
    <message>
        <source>Select a backup folder</source>
        <translation>Yedekleme klasörü seç</translation>
    </message>
    <message>
        <source>Files update successful!
Please reboot the application to access the updated documents.</source>
        <translation>Dosyaların güncellenmesi tamamlandı!
Güncellenen dökümanlara erişmek için uygulamayı yeniden başlatın.</translation>
    </message>
    <message>
        <source>An error occured during the update. The files have not been affected.</source>
        <translation>Güncelleme sırasında bir hata oluştu. Dosyalar değişmedi yada etilenmedi.</translation>
    </message>
    <message>
        <source>Files update results</source>
        <translation>Dosya güncelleme sonucu</translation>
    </message>
    <message>
        <source>Updating file </source>
        <translation>Dosya güncelleniyor</translation>
    </message>
    <message>
        <source>Please wait the import process will start soon...</source>
        <translation>Lütfen bekleyin! İçer aktarım işlemi birazdan başlayacak ...</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Sonra hatırlat</translation>
    </message>
</context>
<context>
    <name>UBWebPluginWidget</name>
    <message>
        <source>Loading...</source>
        <translation>Yükleniyor ...</translation>
    </message>
</context>
<context>
    <name>UBWidgetUniboardAPI</name>
    <message>
        <source>%0 called (method=%1, status=%2)</source>
        <translation>%0 cağırıldı (metod=%1, durum=%2)</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublisher</name>
    <message>
        <source>YouTube authentication failed.</source>
        <translation>YouTube kimlik doğrulama başarısız oldu.</translation>
    </message>
    <message>
        <source>Error while uploading video to YouTube (%1)</source>
        <translation>YouTube&apos;a video yüklenirken hata oluştu (%1)</translation>
    </message>
    <message>
        <source>Upload to YouTube in progress %1 %</source>
        <translation>YouTube&apos;a video gönderim işlemi: %1 %</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublishingDialog</name>
    <message>
        <source>Upload</source>
        <translation>Yükle</translation>
    </message>
    <message>
        <source>Autos &amp; Vehicles</source>
        <translation>Otomotiv &amp; Arabalar</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Müzik</translation>
    </message>
    <message>
        <source>Pets &amp; Animals</source>
        <translation>Evcil Hayvanlar &amp; Hayvanlar</translation>
    </message>
    <message>
        <source>Sports</source>
        <translation>Spor</translation>
    </message>
    <message>
        <source>Travel &amp; Events</source>
        <translation>Gezi &amp; Turlar</translation>
    </message>
    <message>
        <source>Gaming</source>
        <translation>Oyun</translation>
    </message>
    <message>
        <source>Comedy</source>
        <translation>Komedi</translation>
    </message>
    <message>
        <source>People &amp; Blogs</source>
        <translation>İnsanlar &amp; Bloglar</translation>
    </message>
    <message>
        <source>News &amp; Politics</source>
        <translation>Haberler &amp; Politika</translation>
    </message>
    <message>
        <source>Entertainment</source>
        <translation>Eğlence</translation>
    </message>
    <message>
        <source>Education</source>
        <translation>Eğitim</translation>
    </message>
    <message>
        <source>Howto &amp; Style</source>
        <translation>Nasıl Yapılır &amp; Stil</translation>
    </message>
    <message>
        <source>Nonprofits &amp; Activism</source>
        <translation>Kar Amacı Gütmeyen &amp; Aktivizm</translation>
    </message>
    <message>
        <source>Science &amp; Technology</source>
        <translation>Bilim &amp; Teknoloji</translation>
    </message>
</context>
<context>
    <name>UBZoomPalette</name>
    <message>
        <source>%1 x</source>
        <translation>%1 x</translation>
    </message>
</context>
<context>
    <name>WBClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Temizle</translation>
    </message>
</context>
<context>
    <name>WBDownloadItem</name>
    <message>
        <source>Save File</source>
        <translation>Dosyayı Kaydet</translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation>İndirme iptal edildi: %1</translation>
    </message>
    <message>
        <source>Error opening saved file: %1</source>
        <translation>Kaydedilen dosya açılırken hata oluştu: %1</translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation>Kaydedilirken hata oluştu: %1</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Network hatası:%1</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>saniye</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>dakika</translation>
    </message>
    <message>
        <source>- %4 %5 remaining</source>
        <translation>- kalan: %4 / %5</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) %4</source>
        <translation>%1 / %2 (%3/saniye) %4</translation>
    </message>
    <message>
        <source>?</source>
        <comment>unknown file size</comment>
        <translation>Geçersiz dosya boyutu?</translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation>%1 / %2 - Durduruldu</translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>byte</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
</context>
<context>
    <name>WBDownloadManager</name>
    <message>
        <source>1 Download</source>
        <translation>1 Adet İndirilen</translation>
    </message>
    <message>
        <source>%1 Downloads</source>
        <comment>always &gt;= 2</comment>
        <translation>%1 Adet İndirilen</translation>
    </message>
</context>
<context>
    <name>WBHistoryModel</name>
    <message>
        <source>Title</source>
        <translation>Başlık</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adres</translation>
    </message>
</context>
<context>
    <name>WBHistoryTreeModel</name>
    <message>
        <source>Earlier Today</source>
        <translation>Gürün Erken Saatleri</translation>
    </message>
    <message>
        <source>%1 items</source>
        <translation>%1 Madde</translation>
    </message>
</context>
<context>
    <name>WBSearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Ara</translation>
    </message>
</context>
<context>
    <name>WBTabBar</name>
    <message>
        <source>New &amp;Tab</source>
        <translation>Yeni &amp;Sekme</translation>
    </message>
    <message>
        <source>Clone Tab</source>
        <translation>Sekmeyi Kolanla</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Sekmeyi Kapat</translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation>Diğer &amp;Sekmeleri Kapat</translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation>Sekmeyi Yeniden Yükle</translation>
    </message>
    <message>
        <source>Reload All Tabs</source>
        <translation>Tüm Sekmeleri Yeniden Yükle</translation>
    </message>
</context>
<context>
    <name>WBTabWidget</name>
    <message>
        <source>Recently Closed Tabs</source>
        <translation>Recently Closed Tabs</translation>
    </message>
    <message>
        <source>(Untitled)</source>
        <translation>(Başlıksız)</translation>
    </message>
</context>
<context>
    <name>WBToolbarSearch</name>
    <message>
        <source>Search</source>
        <translation>Ara</translation>
    </message>
    <message>
        <source>No Recent Searches</source>
        <translation>Son Zamanlarda Yapılan Arama Bulunmamakta</translation>
    </message>
    <message>
        <source>Recent Searches</source>
        <translation>Son Yapılan Aramalar</translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation>Son Yapılan Aramaları Temizle</translation>
    </message>
</context>
<context>
    <name>WBWebPage</name>
    <message>
        <source>Download</source>
        <translation>İndir</translation>
    </message>
    <message>
        <source>Add to Current Document</source>
        <translation>Mevcut Dökümana Ekle</translation>
    </message>
    <message>
        <source>PDF</source>
        <translation>PDF</translation>
    </message>
    <message>
        <source>Error loading page: %1</source>
        <translation>Sayfa yüklenirken hata oluştu: %1</translation>
    </message>
    <message>
        <source>Download PDF Document: would you prefer to download the PDF file or add it to the current OpenBoard document?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WBWebView</name>
    <message>
        <source>Open in New Tab</source>
        <translation>Yeni Sekmede Aç</translation>
    </message>
</context>
<context>
    <name>XPDFRenderer</name>
    <message>
        <source>Processing...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>YouTubePublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>Podcasti YouTube&apos;da Yayınla</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Başlık</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Açıklama</translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation>Anahtar Kelimeler</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategori</translation>
    </message>
    <message>
        <source>YouTube Username</source>
        <translation>YouTube Kullanıcı Adı</translation>
    </message>
    <message>
        <source>YouTube Password</source>
        <translation>YouTube Şifresi</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;By clicking &apos;Upload,&apos; you certify that you own all rights to the content or that you are authorized by the owner to make the content publicly available on YouTube, and that it otherwise complies with the YouTube Terms of Service located at &lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;By clicking &apos;Upload,&apos; you certify that you own all rights to the content or that you are authorized by the owner to make the content publicly available on YouTube, and that it otherwise complies with the YouTube Terms of Service located at &lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation type="unfinished">OpenBoard</translation>
    </message>
    <message>
        <source>Restore credentials on reboot</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>brushProperties</name>
    <message>
        <source>Opacity</source>
        <translation>Saydamlık</translation>
    </message>
    <message>
        <source>On Light Background</source>
        <translation>Açık Arkaplan Üzerine</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation>Kapalı Arkaplan Üzerine</translation>
    </message>
    <message>
        <source>Line Width</source>
        <translation>Çizgi Genişliği</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Strong</source>
        <translation>Kalın</translation>
    </message>
    <message>
        <source>Fine</source>
        <translation>Hassas</translation>
    </message>
    <message>
        <source>Pen is Pressure Sensitive</source>
        <translation>Kalem Basınca Duyarlıdır</translation>
    </message>
    <message>
        <source>Show preview circle from</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>px</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>capturePublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Diyalog</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Başlık</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Yazar</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Açıklama</translation>
    </message>
</context>
<context>
    <name>documentPublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation type="obsolete">Diyalog</translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="obsolete">Başlık</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation type="obsolete">E-mail</translation>
    </message>
    <message>
        <source>Author</source>
        <translation type="obsolete">Yazar</translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="obsolete">Açıklama</translation>
    </message>
</context>
<context>
    <name>documents</name>
    <message>
        <source>OpenBoard Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Creation date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alphabetical order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort Order</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>preferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Tercihler</translation>
    </message>
    <message>
        <source>Default Settings</source>
        <translation>Geçerli Ayarlar</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>Ekran</translation>
    </message>
    <message>
        <source>Show Page with External Browser</source>
        <translation>Sayfayı Harici Tarayıcıda Göster</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>Sanal Klavye</translation>
    </message>
    <message>
        <source>Keyboard button size:</source>
        <translation type="vanished">Klavye tuş boyutu:</translation>
    </message>
    <message>
        <source>Positioned at the Top (recommended for tablets)</source>
        <translation>Üstte konumlandır (tabletler için tavsiye edilir)</translation>
    </message>
    <message>
        <source>Positioned at the Bottom (recommended for white boards)</source>
        <translation>Altta konumlandır (akıllı tahtalar için tavsiye edilir)</translation>
    </message>
    <message>
        <source>Display Text Under Button</source>
        <translation>Yazıyı Tuşun Altında Göster</translation>
    </message>
    <message>
        <source>Stylus Palette</source>
        <translation>Stylus Paleti</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Yatay</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Dikey</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Hakkında</translation>
    </message>
    <message>
        <source>Software Update</source>
        <translation>Yazılım Güncellemesi</translation>
    </message>
    <message>
        <source>Check software update at launch</source>
        <translation>Başlangıçta yazılım güncellemeleri kontrol et</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Ana Sayfa:</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Araç Çubuğu</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Dolma Kalem</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Fosforlu Kalem</translation>
    </message>
    <message>
        <source>version : …</source>
        <translation>Versiyon: ...</translation>
    </message>
    <message>
        <source>Licences</source>
        <translation>Lisanslar</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Network</translation>
    </message>
    <message>
        <source>Show internal web page content on secondary screen or projector</source>
        <translation>Dahili web sayfa içeriğini ikince ekranda yada projektörde göster</translation>
    </message>
    <message>
        <source>Multi display</source>
        <translation>Çoklu ekran</translation>
    </message>
    <message>
        <source>Swap control display and view display</source>
        <translation>Kontrol ekranını ve görütü ekranını yer değiştir</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mod</translation>
    </message>
    <message>
        <source>Mode to start in:</source>
        <translation>Başlangıç modu:</translation>
    </message>
    <message>
        <source>Board</source>
        <translation>Tahta</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Masa Üstü</translation>
    </message>
    <message>
        <source>Proxy User:</source>
        <translation>Proxy Kullanıcısı:</translation>
    </message>
    <message>
        <source>Pass:</source>
        <translation>Şifre:</translation>
    </message>
    <message>
        <source>Credits</source>
        <translation>Künye</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation type="unfinished">Kapalı Arkaplan Üzerine</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation type="unfinished">Saydamlık</translation>
    </message>
    <message>
        <source>On Light Background</source>
        <translation type="unfinished">Açık Arkaplan Üzerine</translation>
    </message>
    <message>
        <source>Swap first and second view displays</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Built-in virtual keyboard button size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use system keyboard (recommended)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open-Sankoré Importer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check if Open-Sankoré data could be imported at launch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Documents Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display date column on alphabetical sort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Empty trash for documents older than</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PDF Rendering</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Improve zoom execution time (can slightly affect rendering quality)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>trapFlashDialog</name>
    <message>
        <source>Trap flash</source>
        <translation>Flash&apos;i tuzakla</translation>
    </message>
    <message>
        <source>Select a flash to trap</source>
        <translation>Tuzağa almak için bir flash öğesi seçin</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation>hakkında:boş</translation>
    </message>
    <message>
        <source>Application name</source>
        <translation>Uygulama adı</translation>
    </message>
    <message>
        <source>Create Application</source>
        <translation>Uygulama Oluştur</translation>
    </message>
</context>
</TS>
